@@ -2,9 +2,10 @@
 Google Cloud Storage Reader
 """
 import os
-from ...data.readers.internals.base_inner_reader import BaseInnerReader
-from ...errors import MissingDependencyError
-from ...utils import paths
+
+from mabel.data.readers.internals.base_inner_reader import BaseInnerReader
+from mabel.errors import MissingDependencyError
+from mabel.utils import paths
 
 try:
     from google.auth.credentials import AnonymousCredentials  # type:ignore
@@ -16,23 +17,18 @@ except ImportError:  # pragma: no cover
 
 
 class GoogleCloudStorageReader(BaseInnerReader):
-
-    RULES = [{"name": "project", "required": False}]
-
-    def __init__(self, project: str, credentials=None, **kwargs):
+    def __init__(self, credentials=None, **kwargs):
         if not google_cloud_storage_installed:  # pragma: no cover
             raise MissingDependencyError(
                 "`google-cloud-storage` is missing, please install or include in requirements.txt"
             )
 
         super().__init__(**kwargs)
-        self.project = project
         self.credentials = credentials
 
     def get_blob_bytes(self, blob_name):
         bucket, object_path, name, extension = paths.get_parts(blob_name)
         blob = get_blob(
-            project=self.project,
             bucket=bucket,
             blob_name=object_path + name + extension,
         )
@@ -44,12 +40,9 @@ class GoogleCloudStorageReader(BaseInnerReader):
 
         # this means we're testing
         if os.environ.get("STORAGE_EMULATOR_HOST") is not None:
-            client = storage.Client(
-                credentials=AnonymousCredentials(),
-                project=self.project,
-            )
+            client = storage.Client(credentials=AnonymousCredentials())
         else:  # pragma: no cover
-            client = storage.Client(project=self.project)
+            client = storage.Client()
 
         gcs_bucket = client.get_bucket(bucket)
         blobs = list(client.list_blobs(bucket_or_name=gcs_bucket, prefix=object_path))
@@ -59,16 +52,13 @@ class GoogleCloudStorageReader(BaseInnerReader):
         ]
 
 
-def get_blob(project: str, bucket: str, blob_name: str):
+def get_blob(bucket: str = None, blob_name: str = None):
 
     # this means we're testing
     if os.environ.get("STORAGE_EMULATOR_HOST") is not None:
-        client = storage.Client(
-            credentials=AnonymousCredentials(),
-            project=project,
-        )
+        client = storage.Client(credentials=AnonymousCredentials())
     else:  # pragma: no cover
-        client = storage.Client(project=project)
+        client = storage.Client()
 
     gcs_bucket = client.get_bucket(bucket)
     blob = gcs_bucket.get_blob(blob_name)
