@@ -24,30 +24,28 @@ limitations under the License.
 # python setup.py build_ext --inplace
 
 import os
-import orjson
 import statistics
 
-from siphashc import siphash
-from operator import itemgetter
+from enum import Enum
 from functools import reduce
-
 from typing import Iterable, Dict, Any, Union
+from warnings import warn
 
-from ...errors import MissingDependencyError
-from ...utils.ipython import is_running_from_ipython
+import orjson
+
+from siphashc import siphash
+
+from mabel.errors import MissingDependencyError
+from mabel.utils.ipython import is_running_from_ipython
 
-from .display import html_table, ascii_table
-from .storage_classes import (
-    StorageClassMemory,
-    StorageClassDisk,
-    StorageClassCompressedMemory,
-)
 from .expression import Expression
+from .display import html_table, ascii_table
 from .dnf_filters import DnfFilters
 from .dumb_iterator import DumbIterator
 from .group_by import GroupBy
-
-from enum import Enum
+from .storage_classes import StorageClassCompressedMemory
+from .storage_classes import StorageClassDisk
+from .storage_classes import StorageClassMemory
 
 
 class STORAGE_CLASS(int, Enum):
@@ -307,10 +305,10 @@ class DictSet(object):
                         "".join([str(item.get(c, "$$")) for c in columns])
                     )
                 else:
-                    # ensure the fields are in the same order
-                    # this is quicker than dealing with dictionaries
-                    hashed_item = hash(
-                        "".join([f"{k}:{item[k]}" for k in sorted(item.keys())])
+                    hashed_item = reduce(
+                        lambda x, y: x ^ y,
+                        [hash(f"{i},{v}") for i, v in enumerate(item.values())],
+                        0,
                     )
                 if hashed_item not in hash_list:
                     yield item
@@ -345,7 +343,7 @@ class DictSet(object):
             return
 
         # if the iterator allows us to access items directly, use that
-        if hasattr(self._iterator, "__getitem__"):
+        if hasattr(self._iterator, "__getitem__"):  # pragma: no cover
             yield from [self._iterator[i] for i in locations]
             return
 
@@ -385,16 +383,13 @@ class DictSet(object):
             raise MissingDependencyError(
                 "`pandas` is missing, please install or include in requirements.txt"
             )
-        return pandas.DataFrame(iter(self._iterator))
+        return pandas.DataFrame([r for r in iter(self._iterator)])
 
     def first(self) -> dict:
         """
         Retun the first item in the DictSet
         """
-        oneth = next(iter(self._iterator), None)
-        if hasattr(oneth, "as_dict"):
-            return oneth.as_dict()  # type:ignore
-        return oneth  # type:ignore
+        return next(iter(self._iterator), None)
 
     def take(self, items: int):
         """
@@ -410,12 +405,13 @@ class DictSet(object):
         This returns a generator.
         """
         for count, item in enumerate(iter(self._iterator)):
-            if count == items:
-                return
             if isinstance(item, dict):
                 yield item
             else:
                 yield item.as_dict()
+            # count is zero-based, if we've read the itemth item, quit
+            if (count + 1) == items:
+                return
 
     def filter(self, filters):
         """
@@ -470,6 +466,9 @@ class DictSet(object):
             return self._iterator.cursor
         return None
 
+    def project(self, columns):
+        return self.select(columns)
+
     def select(self, columns):
         """
         Selects columns from a _DictSet_. If the column doesn't exist it is populated
@@ -481,8 +480,6 @@ class DictSet(object):
         if not isinstance(columns, (list, set, tuple)):
             columns = list([columns])
 
-        columns = set(columns)
-
         if "*" in columns:
 
             def inner_select(it):
