@@ -4,11 +4,11 @@ import datetime
 import threading
 import itertools
 from pydantic import BaseModel  # type:ignore
-from typing import Any, Union
+from typing import Union
 from .writer import Writer
 from .internals.writer_pool import WriterPool
-from ...utils import paths, text
-from ...logging import get_logger
+from mabel.utils import paths, text, dates
+from mabel.logging import get_logger
 
 
 class StreamWriter(Writer):
@@ -22,7 +22,7 @@ class StreamWriter(Writer):
         dataset: str,
         format: str = "zstd",
         idle_timeout_seconds: int = 30,
-        writer_pool_capacity: int = 5,
+        writer_pool_capacity: int = 10,
         **kwargs,
     ):
         """
@@ -64,6 +64,8 @@ class StreamWriter(Writer):
 
         super().__init__(**kwargs)
 
+        self.date = dates.parse_iso(kwargs.get("date"))
+
         self.idle_timeout_seconds = idle_timeout_seconds
 
         # we have a pool of writers of size maximum_writers
@@ -74,7 +76,9 @@ class StreamWriter(Writer):
         self.thread = threading.Thread(target=self.pool_attendant)
         self.thread.name = "mabel-writer-pool-attendant"
         self.thread.daemon = True
+        self.run_pool_attendant = True
         self.thread.start()
+        get_logger().debug("Pool attendant on-duty")
 
     def append(self, record: Union[dict, BaseModel]):
         """
@@ -98,7 +102,9 @@ class StreamWriter(Writer):
         # partition
 
         writes = 0
-        identity = paths.date_format(self.dataset_template, datetime.date.today())
+        identity = paths.date_format(
+            self.dataset_template, (self.date or datetime.datetime.utcnow().date())
+        )
 
         if isinstance(record, BaseModel):
             record = record.dict()
@@ -110,7 +116,9 @@ class StreamWriter(Writer):
                 f"Schema Validation Failed ({self.schema.last_error}) - message being written to {identity}"
             )
 
-        with threading.Lock():
+        lock = threading.Lock()
+        try:
+            lock.acquire(blocking=True, timeout=10)
 
             # get the placeholders from the dataset name
             placeholders = set(re.findall(r"\{(.*?)\}", identity))
@@ -124,10 +132,10 @@ class StreamWriter(Writer):
             values = []
             for placeholder in placeholders:
                 value = record.get(placeholder)
+                if hasattr(value, "as_list"):
+                    value = value.as_list()  # type:ignore
                 if not isinstance(value, list):
                     value = [value]
-                if hasattr(value, "as_list"):
-                    value = value.as_list
                 values.append(value)
             # get the cartesian product of these lists
             # save the result to a set otherwise it's not a cartesian product
@@ -143,40 +151,49 @@ class StreamWriter(Writer):
                         "{" + k + "}", text.sanitize(str(v))
                     )
 
-                print(this_identity)
                 # get the writer and save the record
                 blob_writer = self.writer_pool.get_writer(this_identity)
                 blob_writer.append(record)
                 writes += 1
+        finally:
+            lock.release()
 
         return writes
 
     def finalize(self, **kwargs):
-        with threading.Lock():
+        self.run_pool_attendant = False
+        lock = threading.Lock()
+        try:
+            lock.acquire(blocking=True, timeout=10)
             for blob_writer_identity in self.writer_pool.writers:
                 try:
                     get_logger().debug(
-                        f"Removing {blob_writer_identity} from the writer pool during finalization"
+                        f"Removing from the writer pool during finalization, identity={blob_writer_identity['identity']}, poolsize={len(self.writer_pool.writers)}"
                     )
-                    self.writer_pool.remove_writer(blob_writer_identity)
+                    self.writer_pool.remove_writer(blob_writer_identity["identity"])
                 except Exception as err:
                     get_logger().debug(
                         f"Error finalizing `{blob_writer_identity}`, {type(err).__name__} - {err}"
                     )
+        finally:
+            lock.release()
         return super().finalize()
 
     def pool_attendant(self):
         """
         Writer Pool Management
         """
-        while True:
-            with threading.Lock():
+        while self.run_pool_attendant:
+            lock = threading.Lock()
+            try:
+                lock.acquire(blocking=True, timeout=10)
+
                 # search for pool occupants who haven't had a write recently
                 for blob_writer_identity in self.writer_pool.get_stale_writers(
                     self.idle_timeout_seconds
                 ):
                     get_logger().debug(
-                        f"Evicting {blob_writer_identity} from the writer pool due to inactivity - limit is {self.idle_timeout_seconds} seconds"
+                        f"Evicting {blob_writer_identity} from the writer pool due to inactivity - limit is {self.idle_timeout_seconds} seconds, poolsize={len(self.writer_pool.writers)}"
                     )
                     self.writer_pool.remove_writer(blob_writer_identity)
                 # if we're over capacity, evict the LRU writers
@@ -184,7 +201,13 @@ class StreamWriter(Writer):
                     blob_writer_identity
                 ) in self.writer_pool.nominate_writers_to_evict():
                     get_logger().debug(
-                        f"Evicting {blob_writer_identity} from the writer pool due the pool being over its {self.writer_pool_capacity} capacity"
+                        f"Evicting {blob_writer_identity} from the writer pool due the pool being over its {self.writer_pool_capacity} capacity, poolsize={len(self.writer_pool.writers)}"
                     )
                     self.writer_pool.remove_writer(blob_writer_identity)
-            time.sleep(1)
+
+            finally:
+                lock.release()
+
+            time.sleep(0.1)
+
+        get_logger().debug("Pool attendant off-duty")
